#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'newgamewidget.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWGAMEWIDGET_H
#define UI_NEWGAMEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_NewGameWidget
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *labelPlayer4Name;
    QCheckBox *playerFourHuman;
    QCheckBox *playerThreeHuman;
    QLabel *labelPlayer3Name;
    QLineEdit *playerFourName;
    QLineEdit *playerThreeName;
    QLineEdit *playerTwoName;
    QLabel *labelPlayer2Name;
    QSpinBox *spinNumOfPlayers;
    QCheckBox *playerOneHuman;
    QLabel *numOfPlayersLabel;
    QLineEdit *playerOneName;
    QLabel *labelPlayer1Name;
    QCheckBox *playerTwoHuman;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout1;
    QLabel *labelWidth;
    QSpinBox *spinHeight;
    QLabel *labelHeight;
    QSpinBox *spinWidth;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout2;
    QCheckBox *quickStartCheck;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *NewGameWidget)
    {
        if (NewGameWidget->objectName().isEmpty())
            NewGameWidget->setObjectName(QStringLiteral("NewGameWidget"));
        NewGameWidget->resize(368, 370);
        NewGameWidget->setLayoutDirection(Qt::LeftToRight);
        vboxLayout = new QVBoxLayout(NewGameWidget);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        groupBox = new QGroupBox(NewGameWidget);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setHorizontalSpacing(6);
        gridLayout->setVerticalSpacing(6);
        gridLayout->setContentsMargins(9, 9, 9, 9);
        labelPlayer4Name = new QLabel(groupBox);
        labelPlayer4Name->setObjectName(QStringLiteral("labelPlayer4Name"));

        gridLayout->addWidget(labelPlayer4Name, 4, 0, 1, 1);

        playerFourHuman = new QCheckBox(groupBox);
        playerFourHuman->setObjectName(QStringLiteral("playerFourHuman"));
        playerFourHuman->setEnabled(true);
        playerFourHuman->setChecked(true);

        gridLayout->addWidget(playerFourHuman, 4, 2, 1, 1);

        playerThreeHuman = new QCheckBox(groupBox);
        playerThreeHuman->setObjectName(QStringLiteral("playerThreeHuman"));
        playerThreeHuman->setEnabled(true);
        playerThreeHuman->setChecked(true);

        gridLayout->addWidget(playerThreeHuman, 3, 2, 1, 1);

        labelPlayer3Name = new QLabel(groupBox);
        labelPlayer3Name->setObjectName(QStringLiteral("labelPlayer3Name"));

        gridLayout->addWidget(labelPlayer3Name, 3, 0, 1, 1);

        playerFourName = new QLineEdit(groupBox);
        playerFourName->setObjectName(QStringLiteral("playerFourName"));

        gridLayout->addWidget(playerFourName, 4, 1, 1, 1);

        playerThreeName = new QLineEdit(groupBox);
        playerThreeName->setObjectName(QStringLiteral("playerThreeName"));

        gridLayout->addWidget(playerThreeName, 3, 1, 1, 1);

        playerTwoName = new QLineEdit(groupBox);
        playerTwoName->setObjectName(QStringLiteral("playerTwoName"));

        gridLayout->addWidget(playerTwoName, 2, 1, 1, 1);

        labelPlayer2Name = new QLabel(groupBox);
        labelPlayer2Name->setObjectName(QStringLiteral("labelPlayer2Name"));

        gridLayout->addWidget(labelPlayer2Name, 2, 0, 1, 1);

        spinNumOfPlayers = new QSpinBox(groupBox);
        spinNumOfPlayers->setObjectName(QStringLiteral("spinNumOfPlayers"));
        spinNumOfPlayers->setEnabled(true);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(spinNumOfPlayers->sizePolicy().hasHeightForWidth());
        spinNumOfPlayers->setSizePolicy(sizePolicy);
        spinNumOfPlayers->setMinimum(2);
        spinNumOfPlayers->setMaximum(4);

        gridLayout->addWidget(spinNumOfPlayers, 0, 1, 1, 2);

        playerOneHuman = new QCheckBox(groupBox);
        playerOneHuman->setObjectName(QStringLiteral("playerOneHuman"));
        playerOneHuman->setEnabled(true);
        playerOneHuman->setChecked(true);

        gridLayout->addWidget(playerOneHuman, 1, 2, 1, 1);

        numOfPlayersLabel = new QLabel(groupBox);
        numOfPlayersLabel->setObjectName(QStringLiteral("numOfPlayersLabel"));

        gridLayout->addWidget(numOfPlayersLabel, 0, 0, 1, 1);

        playerOneName = new QLineEdit(groupBox);
        playerOneName->setObjectName(QStringLiteral("playerOneName"));

        gridLayout->addWidget(playerOneName, 1, 1, 1, 1);

        labelPlayer1Name = new QLabel(groupBox);
        labelPlayer1Name->setObjectName(QStringLiteral("labelPlayer1Name"));

        gridLayout->addWidget(labelPlayer1Name, 1, 0, 1, 1);

        playerTwoHuman = new QCheckBox(groupBox);
        playerTwoHuman->setObjectName(QStringLiteral("playerTwoHuman"));
        playerTwoHuman->setEnabled(true);
        playerTwoHuman->setChecked(true);

        gridLayout->addWidget(playerTwoHuman, 2, 2, 1, 1);


        vboxLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(NewGameWidget);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        gridLayout1 = new QGridLayout(groupBox_2);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        gridLayout1->setHorizontalSpacing(6);
        gridLayout1->setVerticalSpacing(6);
        gridLayout1->setContentsMargins(9, 9, 9, 9);
        labelWidth = new QLabel(groupBox_2);
        labelWidth->setObjectName(QStringLiteral("labelWidth"));

        gridLayout1->addWidget(labelWidth, 0, 0, 1, 1);

        spinHeight = new QSpinBox(groupBox_2);
        spinHeight->setObjectName(QStringLiteral("spinHeight"));
        sizePolicy.setHeightForWidth(spinHeight->sizePolicy().hasHeightForWidth());
        spinHeight->setSizePolicy(sizePolicy);
        spinHeight->setMinimum(1);
        spinHeight->setMaximum(30);
        spinHeight->setValue(10);

        gridLayout1->addWidget(spinHeight, 1, 1, 1, 1);

        labelHeight = new QLabel(groupBox_2);
        labelHeight->setObjectName(QStringLiteral("labelHeight"));

        gridLayout1->addWidget(labelHeight, 1, 0, 1, 1);

        spinWidth = new QSpinBox(groupBox_2);
        spinWidth->setObjectName(QStringLiteral("spinWidth"));
        sizePolicy.setHeightForWidth(spinWidth->sizePolicy().hasHeightForWidth());
        spinWidth->setSizePolicy(sizePolicy);
        spinWidth->setMinimum(2);
        spinWidth->setMaximum(50);
        spinWidth->setValue(10);

        gridLayout1->addWidget(spinWidth, 0, 1, 1, 1);


        vboxLayout->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(NewGameWidget);
        groupBox_3->setObjectName(QStringLiteral("groupBox_3"));
        gridLayout2 = new QGridLayout(groupBox_3);
        gridLayout2->setObjectName(QStringLiteral("gridLayout2"));
        gridLayout2->setHorizontalSpacing(6);
        gridLayout2->setVerticalSpacing(6);
        gridLayout2->setContentsMargins(9, 9, 9, 9);
        quickStartCheck = new QCheckBox(groupBox_3);
        quickStartCheck->setObjectName(QStringLiteral("quickStartCheck"));

        gridLayout2->addWidget(quickStartCheck, 0, 0, 1, 1);


        vboxLayout->addWidget(groupBox_3);

        spacerItem = new QSpacerItem(350, 16, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem);

#ifndef UI_QT_NO_SHORTCUT
        labelPlayer4Name->setBuddy(playerFourName);
        labelPlayer3Name->setBuddy(playerThreeName);
        labelPlayer2Name->setBuddy(playerTwoName);
        numOfPlayersLabel->setBuddy(spinNumOfPlayers);
        labelPlayer1Name->setBuddy(playerOneName);
        labelWidth->setBuddy(spinWidth);
        labelHeight->setBuddy(spinHeight);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(spinNumOfPlayers, playerOneName);
        QWidget::setTabOrder(playerOneName, playerOneHuman);
        QWidget::setTabOrder(playerOneHuman, playerTwoName);
        QWidget::setTabOrder(playerTwoName, playerTwoHuman);
        QWidget::setTabOrder(playerTwoHuman, playerThreeName);
        QWidget::setTabOrder(playerThreeName, playerThreeHuman);
        QWidget::setTabOrder(playerThreeHuman, playerFourName);
        QWidget::setTabOrder(playerFourName, playerFourHuman);
        QWidget::setTabOrder(playerFourHuman, spinWidth);
        QWidget::setTabOrder(spinWidth, spinHeight);

        retranslateUi(NewGameWidget);

        QMetaObject::connectSlotsByName(NewGameWidget);
    } // setupUi

    void retranslateUi(QWidget *NewGameWidget)
    {
        NewGameWidget->setWindowTitle(tr2i18n("New Game", 0));
#ifndef UI_QT_NO_WHATSTHIS
        groupBox->setWhatsThis(tr2i18n("Settings for the players in the game", 0));
#endif // QT_NO_WHATSTHIS
        groupBox->setTitle(tr2i18n("Players", 0));
#ifndef UI_QT_NO_WHATSTHIS
        labelPlayer4Name->setWhatsThis(tr2i18n("The name of the fourth player", 0));
#endif // QT_NO_WHATSTHIS
        labelPlayer4Name->setText(tr2i18n("Player 4:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        playerFourHuman->setWhatsThis(tr2i18n("Should this player be controlled by a human", 0));
#endif // QT_NO_WHATSTHIS
        playerFourHuman->setText(tr2i18n("Hum&an?", 0));
#ifndef UI_QT_NO_WHATSTHIS
        playerThreeHuman->setWhatsThis(tr2i18n("Should this player be controlled by a human", 0));
#endif // QT_NO_WHATSTHIS
        playerThreeHuman->setText(tr2i18n("Hu&man?", 0));
#ifndef UI_QT_NO_WHATSTHIS
        labelPlayer3Name->setWhatsThis(tr2i18n("The name of the third player", 0));
#endif // QT_NO_WHATSTHIS
        labelPlayer3Name->setText(tr2i18n("Player 3:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        labelPlayer2Name->setWhatsThis(tr2i18n("The name of the second player", 0));
#endif // QT_NO_WHATSTHIS
        labelPlayer2Name->setText(tr2i18n("Player 2:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        playerOneHuman->setWhatsThis(tr2i18n("Should this player be controlled by a human", 0));
#endif // QT_NO_WHATSTHIS
        playerOneHuman->setText(tr2i18n("&Human?", 0));
#ifndef UI_QT_NO_WHATSTHIS
        numOfPlayersLabel->setWhatsThis(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">How many players will be in the game</p></body></html>", 0));
#endif // QT_NO_WHATSTHIS
        numOfPlayersLabel->setText(tr2i18n("Number of players:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        labelPlayer1Name->setWhatsThis(tr2i18n("The name of the first player", 0));
#endif // QT_NO_WHATSTHIS
        labelPlayer1Name->setText(tr2i18n("Player 1:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        playerTwoHuman->setWhatsThis(tr2i18n("Should this player be controlled by a human", 0));
#endif // QT_NO_WHATSTHIS
        playerTwoHuman->setText(tr2i18n("H&uman?", 0));
#ifndef UI_QT_NO_WHATSTHIS
        groupBox_2->setWhatsThis(tr2i18n("Settings for the game board", 0));
#endif // QT_NO_WHATSTHIS
        groupBox_2->setTitle(tr2i18n("Game Board", 0));
#ifndef UI_QT_NO_WHATSTHIS
        labelWidth->setWhatsThis(tr2i18n("The number of squares the area is wide", 0));
#endif // QT_NO_WHATSTHIS
        labelWidth->setText(tr2i18n("Width:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        labelHeight->setWhatsThis(tr2i18n("The number of squares the area is high", 0));
#endif // QT_NO_WHATSTHIS
        labelHeight->setText(tr2i18n("Height:", 0));
#ifndef UI_QT_NO_WHATSTHIS
        groupBox_3->setWhatsThis(tr2i18n("Settings for the game", 0));
#endif // QT_NO_WHATSTHIS
        groupBox_3->setTitle(tr2i18n("Game Settings", 0));
#ifndef UI_QT_NO_WHATSTHIS
        quickStartCheck->setWhatsThis(tr2i18n("Partially fill in the board automatically before the game starts", 0));
#endif // QT_NO_WHATSTHIS
        quickStartCheck->setText(tr2i18n("Quick start", 0));
    } // retranslateUi

};

namespace Ui {
    class NewGameWidget: public Ui_NewGameWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NEWGAMEWIDGET_H

