/****************************************************************************
** Meta object code from reading C++ file 'ksquaresgame.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/ksquares-17.04.3/src/ksquaresgame.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QVector>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ksquaresgame.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KSquaresGame_t {
    QByteArrayData data[11];
    char stringdata0[130];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KSquaresGame_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KSquaresGame_t qt_meta_stringdata_KSquaresGame = {
    {
QT_MOC_LITERAL(0, 0, 12), // "KSquaresGame"
QT_MOC_LITERAL(1, 13, 11), // "takeTurnSig"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 15), // "KSquaresPlayer*"
QT_MOC_LITERAL(4, 42, 8), // "gameOver"
QT_MOC_LITERAL(5, 51, 23), // "QVector<KSquaresPlayer>"
QT_MOC_LITERAL(6, 75, 8), // "drawLine"
QT_MOC_LITERAL(7, 84, 10), // "drawSquare"
QT_MOC_LITERAL(8, 95, 13), // "highlightMove"
QT_MOC_LITERAL(9, 109, 14), // "addLineToIndex"
QT_MOC_LITERAL(10, 124, 5) // "index"

    },
    "KSquaresGame\0takeTurnSig\0\0KSquaresPlayer*\0"
    "gameOver\0QVector<KSquaresPlayer>\0"
    "drawLine\0drawSquare\0highlightMove\0"
    "addLineToIndex\0index"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KSquaresGame[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,
       4,    1,   47,    2, 0x06 /* Public */,
       6,    2,   50,    2, 0x06 /* Public */,
       7,    2,   55,    2, 0x06 /* Public */,
       8,    1,   60,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    1,   63,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 5,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor,    2,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor,    2,    2,
    QMetaType::Void, QMetaType::Int,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,   10,

       0        // eod
};

void KSquaresGame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KSquaresGame *_t = static_cast<KSquaresGame *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->takeTurnSig((*reinterpret_cast< KSquaresPlayer*(*)>(_a[1]))); break;
        case 1: _t->gameOver((*reinterpret_cast< const QVector<KSquaresPlayer>(*)>(_a[1]))); break;
        case 2: _t->drawLine((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QColor(*)>(_a[2]))); break;
        case 3: _t->drawSquare((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QColor(*)>(_a[2]))); break;
        case 4: _t->highlightMove((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->addLineToIndex((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KSquaresGame::*_t)(KSquaresPlayer * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KSquaresGame::takeTurnSig)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KSquaresGame::*_t)(const QVector<KSquaresPlayer> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KSquaresGame::gameOver)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KSquaresGame::*_t)(int , QColor );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KSquaresGame::drawLine)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KSquaresGame::*_t)(int , QColor );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KSquaresGame::drawSquare)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KSquaresGame::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KSquaresGame::highlightMove)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject KSquaresGame::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KSquaresGame.data,
      qt_meta_data_KSquaresGame,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KSquaresGame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSquaresGame::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KSquaresGame.stringdata0))
        return static_cast<void*>(const_cast< KSquaresGame*>(this));
    return QObject::qt_metacast(_clname);
}

int KSquaresGame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void KSquaresGame::takeTurnSig(KSquaresPlayer * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KSquaresGame::gameOver(const QVector<KSquaresPlayer> & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KSquaresGame::drawLine(int _t1, QColor _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KSquaresGame::drawSquare(int _t1, QColor _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KSquaresGame::highlightMove(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_END_MOC_NAMESPACE
