/****************************************************************************
** Meta object code from reading C++ file 'ksquareswindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/ksquares-17.04.3/src/ksquareswindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QVector>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ksquareswindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KSquaresWindow_t {
    QByteArrayData data[14];
    char stringdata0[182];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KSquaresWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KSquaresWindow_t qt_meta_stringdata_KSquaresWindow = {
    {
QT_MOC_LITERAL(0, 0, 14), // "KSquaresWindow"
QT_MOC_LITERAL(1, 15, 14), // "showHighscores"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 7), // "gameNew"
QT_MOC_LITERAL(4, 39, 9), // "gameReset"
QT_MOC_LITERAL(5, 49, 12), // "aiChooseLine"
QT_MOC_LITERAL(6, 62, 10), // "initObject"
QT_MOC_LITERAL(7, 73, 18), // "optionsPreferences"
QT_MOC_LITERAL(8, 92, 14), // "playerTakeTurn"
QT_MOC_LITERAL(9, 107, 15), // "KSquaresPlayer*"
QT_MOC_LITERAL(10, 123, 13), // "currentPlayer"
QT_MOC_LITERAL(11, 137, 8), // "gameOver"
QT_MOC_LITERAL(12, 146, 23), // "QVector<KSquaresPlayer>"
QT_MOC_LITERAL(13, 170, 11) // "_playerList"

    },
    "KSquaresWindow\0showHighscores\0\0gameNew\0"
    "gameReset\0aiChooseLine\0initObject\0"
    "optionsPreferences\0playerTakeTurn\0"
    "KSquaresPlayer*\0currentPlayer\0gameOver\0"
    "QVector<KSquaresPlayer>\0_playerList"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KSquaresWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   54,    2, 0x0a /* Public */,
       3,    0,   55,    2, 0x0a /* Public */,
       4,    0,   56,    2, 0x0a /* Public */,
       5,    0,   57,    2, 0x08 /* Private */,
       6,    0,   58,    2, 0x08 /* Private */,
       7,    0,   59,    2, 0x08 /* Private */,
       8,    1,   60,    2, 0x08 /* Private */,
      11,    1,   63,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 12,   13,

       0        // eod
};

void KSquaresWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KSquaresWindow *_t = static_cast<KSquaresWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->showHighscores(); break;
        case 1: _t->gameNew(); break;
        case 2: _t->gameReset(); break;
        case 3: _t->aiChooseLine(); break;
        case 4: _t->initObject(); break;
        case 5: _t->optionsPreferences(); break;
        case 6: _t->playerTakeTurn((*reinterpret_cast< KSquaresPlayer*(*)>(_a[1]))); break;
        case 7: _t->gameOver((*reinterpret_cast< const QVector<KSquaresPlayer>(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject KSquaresWindow::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_KSquaresWindow.data,
      qt_meta_data_KSquaresWindow,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KSquaresWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSquaresWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KSquaresWindow.stringdata0))
        return static_cast<void*>(const_cast< KSquaresWindow*>(this));
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KSquaresWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
